from datadog_api_client.v1.model.formula_and_function_metric_aggregation import (
    FormulaAndFunctionMetricAggregation
)
from typing import Dict, Literal, Union
from .widget_aggregation_type import WidgetAggregationType


class WidgetAggregationTypeMap:

    def __init__(self) -> None:
        self._types: Dict[
            Union[
                Literal['average'],
                Literal['total'],
                Literal['maximum'],
                Literal['minimum']
            ],
            Union[
                WidgetAggregationType.AVERAGE,
                WidgetAggregationType.TOTAL,
                WidgetAggregationType.MAXIMUM,
                WidgetAggregationType.MINIMUM
            ]
        ] = {
            'average': WidgetAggregationType.AVERAGE,
            'total': WidgetAggregationType.TOTAL,
            'maximum': WidgetAggregationType.MAXIMUM,
            'minimum': WidgetAggregationType.MINIMUM
        }

        self._datadog_types: Dict[
            Union[
                Literal['average'],
                Literal['total'],
                Literal['maximum'],
                Literal['minimum']
            ],
            Union[
                Literal['avg'],
                Literal['sum'],
                Literal['max'],
                Literal['min']
            ]
        ] = {
            'average': 'avg',
            'total': 'sum',
            'maximum': 'max',
            'minimum': 'min'
        }

        self._formula_types: Dict[
            Union[
                Literal['average'],
                Literal['total'],
                Literal['maximum'],
                Literal['minimum']
            ],
            Union[
                FormulaAndFunctionMetricAggregation.AVG,
                FormulaAndFunctionMetricAggregation.SUM,
                FormulaAndFunctionMetricAggregation.MAX,
                FormulaAndFunctionMetricAggregation.MIN
            ]
        ] = {
            'average': FormulaAndFunctionMetricAggregation.AVG,
            'total': FormulaAndFunctionMetricAggregation.SUM,
            'maximum': FormulaAndFunctionMetricAggregation.MAX,
            'minimum': FormulaAndFunctionMetricAggregation.MIN
        }

    def __iter__(self):
        for aggregation_type in self._types.values():
            yield aggregation_type

    def __getitem__(
        self,
        aggregation_type: Union[
            Literal['average'],
            Literal['total'],
            Literal['maximum'],
            Literal['minimum']
        ]
    ):
        return self._types.get(
            aggregation_type,
            WidgetAggregationType.AVERAGE
        )
    
    def get(
        self,
        aggregation_type: Union[
            Literal['average'],
            Literal['total'],
            Literal['maximum'],
            Literal['minimum']
        ]
    ):
        return self._types.get(aggregation_type)
    
    def map_to_datadog_type(
        self,
        aggregation_type: Union[
            Literal['average'],
            Literal['total'],
            Literal['maximum'],
            Literal['minimum']
        ]
    ):
        return self._datadog_types.get(aggregation_type)
    
    def map_to_formula_type(
        self,
        aggregation_type: Union[
            Literal['average'],
            Literal['total'],
            Literal['maximum'],
            Literal['minimum']
        ]         
    ):
        return self._formula_types.get(aggregation_type)



import os
import json
import datetime
from typing import (
    Literal, 
    Union, 
    Dict, 
    Any
)
from metrik.connectors import Connector
from metrik.logging.table import MetrikTable
from metrik.metrics import (
    MetricStore
)


def query_metric(
    metric_id: str,
    name: str,
    kind: str,
    group: str,
    newer_than: str,
    older_than: str,
    search: str,
    config: str,
    timeout: float
):
    pass



from enum import Enum


class ExtraSmallSize:
    WIDTH=3
    HEIGHT=2


class SmallSize:
    WIDTH=4
    HEIGHT=3


class MediumSize:
    WIDTH=6
    HEIGHT=4


class LargeSize:
    WIDTH=9
    HEIGHT=6


class ExtraLargeSize:
    WIDTH=12
    HEIGHT=8
    

class SizeType(Enum):
    EXTRA_SMALL=ExtraSmallSize()
    SMALL=SmallSize()
    MEDIUM=MediumSize()
    LARGE=LargeSize()
    EXTRA_LARGE=ExtraLargeSize()


def seconds_to_human_string(seconds: float):

    minutes, seconds = divmod(seconds, 60)
    hours, minutes = divmod(minutes, 60)
    days, hours = divmod(hours, 24)

    format_string = ''

    if days > 0:
        format_string = f'{days}d'

    if hours > 0:
        format_string = f'{format_string}{hours}h '

    if minutes > 0:
        format_string = f'{format_string}{minutes}m '

    formatted_seconds = '{s:.2f}'.format(
        s=seconds
    )

    format_string = f'{format_string}{formatted_seconds}s'

    return format_string